# Table of Contents

* [Introduction](intro.md)
  
  * [“Turn your data preparation nightmares into a dream.”](intro.md#turn-your-data-preparation-nightmares-into-a-dream)
    
  * [Why Artifician?](intro.md#why-artifician)
    
  * [Simple Example](intro.md#simple-example)
    
  * [Without Artifician](intro.md#without-artifician)
  
  * [Using Artifician](intro.md#using-artifician)
  
  * [Output](intro.md#output)
 
* [Getting Started with Artifician](getting_started.md)
  
  * [Pre-requisites](getting_started.md#pre-requisites)
    
  * [Installation](getting_started.md#installation)
    
  * [Using pip](getting_started.md#using-pip)
    
  * [Using conda](getting_started.md#using-conda)
    
  * [Verify Installation](getting_started.md#verify-installation)
    
  * [Next Steps](getting_started.md#next-steps)
 
* [Quick Start](quick_start.md)

  * [Define Extractor](quick_start.md#define-extractor)

  * [Initialize components](quick_start.md#initialize-components)
    
  * [Subscriptions](quick_start.md#subscriptions)
 
  * [Dataset Preparation](quick_start.md#dataset-preparation)
    
  * [Output](quick_start.md#output)
    
* [Advanced Concepts](advanced_concepts.md)
  
  * [Processor Chain Manager](processor_chain_manager.md)
 
    * [Overview](processor_chain_manager.md#overview)
    
    * [Key Features](processor_chain_manager.md#key-features)
      
    * [Syntax Showcase](processor_chain_manager.md#syntax-showcase)
      
    * [Example Scenario: NLP Processing Pipeline](processor_chain_manager.md#example-scenario-nlp-processing-pipeline)
      
    * [Building an NLP Pipeline with PCM](processor_chain_manager.md#building-an-nlp-pipeline-with-pcm)
      
    * [Output](processor_chain_manager.md#output)
      
  * [Defining Custom Extractors](define_extractors.md)
    
    * [Introduction](define_extractors.md#introduction)
      
    * [Why Custom Extractors?](define_extractors.md#why-custom-extractors)
      
    * [How Extractors Work](define_extractors.md#how-extractors-work)
      
    * [Example of a Simple Extractor](define_extractors.md#example-of-a-simple-extractor)
      
    * [Integrating Custom Extractors](define_extractors.md#integrating-custom-extractors)
      
    * [Advanced Usage](define_extractors.md#advanced-usage)
      
    * [Conclusion](define_extractors.md#conclusion)
  
  * [Defining Custom Processors](define_processor.md)
    
    * [Introduction](define_processor.md#introduction)
      
    * [Why Custom Processors?](define_processor.md#why-custom-processors)
      
    * [How Processors Work](define_processor.md#how-processors-work)
      
    * [Example of a Simple Processor](define_processor.md#example-of-a-simple-processor)
      
    * [Integrating Custom Processors](define_processor.md#integrating-custom-processors)
      
    * [Advanced Usage](define_processor.md#advanced-usage)
      
    * [Conclusion](define_processor.md#conclusion)
      
  * [Library Architecture](library_architecture.md)
    
    * [Events](library_architecture.md#events)
      
    * [Dataset](library_architecture.md#dataset)
      
    * [Feature Definition](library_architecture.md#feature-definition)
      
    * [Processors](library_architecture.md#processors)
      
    * [Extractors](library_architecture.md#extractors)
      
* [API Reference](api.md)
